<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>{% block title %}cuti - AI Terminal Interface{% endblock %}</title>
    
    <!-- Google Fonts -->
    <link rel="preconnect" href="https://fonts.googleapis.com">
    <link rel="preconnect" href="https://fonts.gstatic.com" crossorigin>
    <link href="https://fonts.googleapis.com/css2?family=Inter:wght@300;400;500;600;700&family=JetBrains+Mono:ital,wght@0,400;0,500;0,600;1,400&display=swap" rel="stylesheet">
    
    <!-- Font Awesome Icons -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">
    
    <!-- Alpine.js -->
    <script src="https://unpkg.com/alpinejs@3.x.x/dist/cdn.min.js" defer></script>
    
    <!-- Main CSS -->
    <link rel="stylesheet" href="{{ url_for('static', path='css/main.css') }}?v=7">
    
    {% block head %}{% endblock %}
</head>
<body{% if body_class %} class="{{ body_class }}"{% endif %}{% if alpine_data %} x-data="{{ alpine_data }}"{% endif %} x-init="init()">
    {% include 'components/header_modern.html' %}
    
    <main class="content-wrapper">
        {% block content %}{% endblock %}
    </main>
    
    <!-- Main JavaScript -->
    <script src="{{ url_for('static', path='js/app.js') }}?v=6"></script>
    
    {% block scripts %}{% endblock %}
</body>
</html>